@@ -78,14 +78,9 @@ class JailThread(Thread):
 					print(e)
 		self.run = run_with_except_hook
 
-	if sys.version_info >= (3,): # pragma: 2.x no cover
-		def _bootstrap(self):
-			prctl_set_th_name(self.name)
-			return super(JailThread, self)._bootstrap();
-	else: # pragma: 3.x no cover
-		def __bootstrap(self):
-			prctl_set_th_name(self.name)
-			return Thread._Thread__bootstrap(self)
+	def _bootstrap(self):
+		prctl_set_th_name(self.name)
+		return super(JailThread, self)._bootstrap();
 
 	@abstractmethod
 	def status(self, flavor="basic"): # pragma: no cover - abstract
@@ -125,9 +120,6 @@ class JailThread(Thread):
 		if self.active is not None:
 			super(JailThread, self).join()
 
-## python 2.x replace binding of private __bootstrap method:
-if sys.version_info < (3,): # pragma: 3.x no cover
-	JailThread._Thread__bootstrap = JailThread._JailThread__bootstrap
 ## python 3.9, restore isAlive method:
-elif not hasattr(JailThread, 'isAlive'): # pragma: 2.x no cover
+if not hasattr(JailThread, 'isAlive'):
 	 JailThread.isAlive = JailThread.is_alive
