@@ -39,7 +39,7 @@ try:
 	Fail2BanDb = database.Fail2BanDb
 except ImportError: # pragma: no cover
 	Fail2BanDb = None
-from .utils import LogCaptureTestCase, logSys as DefLogSys
+from .utils import LogCaptureTestCase, logSys as DefLogSys, uni_decode
 
 TEST_FILES_DIR = os.path.join(os.path.dirname(__file__), "files")
 
@@ -67,7 +67,7 @@ class DatabaseTest(LogCaptureTestCase):
 
 	@property
 	def db(self):
-		if isinstance(self._db, basestring) and self._db == ':auto-create-in-memory:':
+		if isinstance(self._db, str) and self._db == ':auto-create-in-memory:':
 			self._db = getFail2BanDb(self.dbFilename)
 		return self._db
 	@db.setter
@@ -114,9 +114,32 @@ class DatabaseTest(LogCaptureTestCase):
 			self.jail.name in self.db.getJailNames(),
 			"Jail not retained in Db after disconnect reconnect.")
 
+	@staticmethod
+	def _mockupFailedDB(): # pragma: no cover -- only sqlite >= 3.42
+		"""[Mock-Up] broken connect to cover reparable restore."""
+		_org_connect = sqlite3.connect;
+		class _mckp_Cursor(sqlite3.Cursor):
+			def execute(*args, **kwargs):
+				# intended BOOM (simulate broken database):
+				raise sqlite3.Error("[mock-up] broken database");
+		class _mckp_Connection(sqlite3.Connection):
+			def cursor(*args, **kwargs):
+				return _mckp_Cursor(*args, **kwargs)
+		def _mckp_connect(*args, **kwargs):
+			DefLogSys.debug("[mock-up] broken connect to cover reparable restore")
+			# restore original connect immediately:
+			sqlite3.connect = _org_connect
+			# return mockup connect (caused BOOM during first cursor execute):
+			return _mckp_Connection(*args, **kwargs);
+		sqlite3.connect = _mckp_connect;
+
 	def testRepairDb(self):
-		if not Utils.executeCmd("sqlite3 --version"): # pragma: no cover
+		ret = Utils.executeCmd("sqlite3 --version", output=True)
+		if not ret or not ret[0]: # pragma: no cover
 			raise unittest.SkipTest("no sqlite3 command")
+		# version:
+		ret = uni_decode(ret[1]).split(' ')
+		ret = tuple(map(int, (str(ret[0]).split('.'))))if ret else (3,0,0);
 		self.db = None
 		if self.dbFilename is None: # pragma: no cover
 			_, self.dbFilename = tempfile.mkstemp(".db", "fail2ban_")
@@ -124,17 +147,20 @@ class DatabaseTest(LogCaptureTestCase):
 		#   - 14000 bytes - seems to be reparable,
 		#   - 4000  bytes - is totally broken.
 		for truncSize in (14000, 4000):
+			if truncSize >= 14000 and ret > (3,42): # pragma: no cover -- only sqlite >= 3.42
+				truncSize = 14400
+				self._mockupFailedDB(); # mock-up it to ensure it fails by open
 			self.pruneLog("[test-repair], next phase - file-size: %d" % truncSize)
 			shutil.copyfile(
 				os.path.join(TEST_FILES_DIR, 'database_v1.db'), self.dbFilename)
-			# produce currupt database:
+			# produce corrupt database:
 			f = os.open(self.dbFilename, os.O_RDWR)
 			os.ftruncate(f, truncSize)
 			os.close(f)
 			# test repair:
 			try:
 				self.db = Fail2BanDb(self.dbFilename)
-				if truncSize == 14000: # restored:
+				if truncSize >= 14000: # restored:
 					self.assertLogged("Repair seems to be successful",
 						"Check integrity", "Database updated", all=True)
 					self.assertEqual(self.db.getLogPaths(), set(['/tmp/Fail2BanDb_pUlZJh.log']))
@@ -159,7 +185,7 @@ class DatabaseTest(LogCaptureTestCase):
 			self.db = Fail2BanDb(self.dbFilename)
 			self.assertEqual(self.db.getJailNames(), set(['DummyJail #29162448 with 0 tickets']))
 			self.assertEqual(self.db.getLogPaths(), set(['/tmp/Fail2BanDb_pUlZJh.log']))
-			ticket = FailTicket("127.0.0.1", 1388009242.26, [u"abc\n"])
+			ticket = FailTicket("127.0.0.1", 1388009242.26, ["abc\n"])
 			self.assertEqual(self.db.getBans()[0], ticket)
 
 			self.assertEqual(self.db.updateDb(Fail2BanDb.__version__), Fail2BanDb.__version__)
@@ -185,9 +211,9 @@ class DatabaseTest(LogCaptureTestCase):
 		self.assertEqual(len(bans), 2)
 		# compare first ticket completely:
 		ticket = FailTicket("1.2.3.7", 1417595494, [
-			u'Dec  3 09:31:08 f2btest test:auth[27658]: pam_unix(test:auth): authentication failure; logname= uid=0 euid=0 tty=test ruser= rhost=1.2.3.7',
-			u'Dec  3 09:31:32 f2btest test:auth[27671]: pam_unix(test:auth): authentication failure; logname= uid=0 euid=0 tty=test ruser= rhost=1.2.3.7',
-			u'Dec  3 09:31:34 f2btest test:auth[27673]: pam_unix(test:auth): authentication failure; logname= uid=0 euid=0 tty=test ruser= rhost=1.2.3.7'
+			'Dec  3 09:31:08 f2btest test:auth[27658]: pam_unix(test:auth): authentication failure; logname= uid=0 euid=0 tty=test ruser= rhost=1.2.3.7',
+			'Dec  3 09:31:32 f2btest test:auth[27671]: pam_unix(test:auth): authentication failure; logname= uid=0 euid=0 tty=test ruser= rhost=1.2.3.7',
+			'Dec  3 09:31:34 f2btest test:auth[27673]: pam_unix(test:auth): authentication failure; logname= uid=0 euid=0 tty=test ruser= rhost=1.2.3.7'
 		])
 		ticket.setAttempt(3)
 		self.assertEqual(bans[0], ticket)
@@ -287,11 +313,11 @@ class DatabaseTest(LogCaptureTestCase):
 		# invalid + valid, invalid + valid unicode, invalid + valid dual converted (like in filter:readline by fallback) ...
 		tickets = [
 		  FailTicket("127.0.0.1", 0, ['user "test"', 'user "\xd1\xe2\xe5\xf2\xe0"', 'user "\xc3\xa4\xc3\xb6\xc3\xbc\xc3\x9f"']),
-		  FailTicket("127.0.0.2", 0, ['user "test"', u'user "\xd1\xe2\xe5\xf2\xe0"', u'user "\xc3\xa4\xc3\xb6\xc3\xbc\xc3\x9f"']),
+		  FailTicket("127.0.0.2", 0, ['user "test"', 'user "\xd1\xe2\xe5\xf2\xe0"', 'user "\xc3\xa4\xc3\xb6\xc3\xbc\xc3\x9f"']),
 		  FailTicket("127.0.0.3", 0, ['user "test"', b'user "\xd1\xe2\xe5\xf2\xe0"', b'user "\xc3\xa4\xc3\xb6\xc3\xbc\xc3\x9f"']),
-		  FailTicket("127.0.0.4", 0, ['user "test"', 'user "\xd1\xe2\xe5\xf2\xe0"', u'user "\xe4\xf6\xfc\xdf"']),
+		  FailTicket("127.0.0.4", 0, ['user "test"', 'user "\xd1\xe2\xe5\xf2\xe0"', 'user "\xe4\xf6\xfc\xdf"']),
 		  FailTicket("127.0.0.5", 0, ['user "test"', 'unterminated \xcf']),
-		  FailTicket("127.0.0.6", 0, ['user "test"', u'unterminated \xcf']),
+		  FailTicket("127.0.0.6", 0, ['user "test"', 'unterminated \xcf']),
 		  FailTicket("127.0.0.7", 0, ['user "test"', b'unterminated \xcf'])
 		]
 		for ticket in tickets:
