@@ -146,7 +146,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 			"test", r"^(?:(?P<type>A)|B)? (?(typo)...) from <ADDR>"
 		))
 		self.assertLogged("Unable to compile regular expression")
-		self.assertLogged("unknown group name: 'typo'", "at position 23", all=False); # details of failed compilation
+		self.assertLogged("unknown group name", "at position 23", all=False); # details of failed compilation
 
 	def testWrongIngnoreRE(self):
 		self.assertFalse(_test_exec(
@@ -221,10 +221,17 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		self.pruneLog()
 		self.assertTrue(_test_exec(
 			"-d", "^Epoch",
-			"1490349000 test failed.dns.ch", "^\s*test <F-ID>\S+</F-ID>"
+			"1490349000 test failed.dns.ch", r"^\s*test <F-ID>\S+</F-ID>"
 		))
 		self.assertLogged('Lines: 1 lines, 0 ignored, 1 matched, 0 missed', all=True)
 		self.assertNotLogged('Unable to find a corresponding IP address')
+		# no confusion to IP/CIDR
+		self.pruneLog()
+		self.assertTrue(_test_exec(
+			"-d", "^Epoch", "-o", "id",
+			"1490349000 test this/is/some/path/32", r"^\s*test <F-ID>\S+</F-ID>"
+		))
+		self.assertLogged('this/is/some/path/32', all=True)
 
 	def testDirectRE_2(self):
 		self.assertTrue(_test_exec(
@@ -251,7 +258,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		"-l", "notice", # put down log-level, because of too many debug-messages
 			"-v", "--verbose-date", "--print-all-matched", "--print-all-ignored",
 			"-c", CONFIG_DIR,
-			FILENAME_SSHD, "sshd"
+			FILENAME_SSHD, "sshd.conf"
 		))
 		# test failure line and not-failure lines both presents:
 		self.assertLogged("[29116]: User root not allowed because account is locked",
@@ -262,7 +269,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		"-l", "notice", # put down log-level, because of too many debug-messages
 			"-vv", "-c", CONFIG_DIR,
 			"Dec 31 11:59:59 [sshd] error: PAM: Authentication failure for kevin from 192.0.2.1",
-			"sshd[logtype=short]"
+			"filter.d/sshd[logtype=short]"
 		))
 		# tet logtype is specified and set in real options:
 		self.assertLogged("Real  filter options :", "'logtype': 'short'", all=True)
@@ -281,6 +288,16 @@ class Fail2banRegexTest(LogCaptureTestCase):
 			"[29116]: User root not allowed because account is locked",
 			"[29116]: Received disconnect from 192.0.2.4", all=True)
 
+	def testLoadFromJail(self):
+		self.assertTrue(_test_exec(
+		"-l", "notice", # put down log-level, because of too many debug-messages
+			"-c", CONFIG_DIR, '-vv',
+			FILENAME_ZZZ_SSHD, "sshd[logtype=short]"
+		))
+		# test it was jail not filter:
+		self.assertLogged(
+			"Use %11s jail : %s" % ('','sshd'))
+
 	def testMultilineSshd(self):
 		# by the way test of missing lines by multiline in `for bufLine in orgLineBuffer[int(fullBuffer):]`
 		self.assertTrue(_test_exec(
@@ -424,31 +441,31 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		)
 		_test = lambda *args: _test_exec(*(opts + args))
 		# with MLFID from prefregex and IP after failure obtained from F-NOFAIL RE:
-		self.assertTrue(_test('-o', 'IP:<ip>', log, 'sshd'))
+		self.assertTrue(_test('-o', 'IP:<ip>', log, 'sshd.conf'))
 		self.assertLogged('IP:192.0.2.76')
 		self.pruneLog()
 		# test diverse ID/IP constellations:
-		def _test_variants(flt="sshd", prefix=""):
+		def _test_variants(flt="sshd.conf", prefix=""):
 			# with different ID/IP from failregex (ID/User from first, IP from second message):
 			self.assertTrue(_test('-o', 'ID:"<fid>" | IP:<ip> | U:<F-USER>', log, 
 				flt+'[failregex="'
-				  '^'+prefix+'<F-ID>User <F-USER>\S+</F-USER></F-ID> not allowed\n'
-				  '^'+prefix+'Received disconnect from <ADDR>'
+				  '^'+prefix+r'<F-ID>User <F-USER>\S+</F-USER></F-ID> not allowed'+'\n'
+				  '^'+prefix+r'Received disconnect from <ADDR>'
 				'"]'))
 			self.assertLogged('ID:"User root" | IP:192.0.2.76 | U:root')
 			self.pruneLog()
 			# with different ID/IP from failregex (User from first, ID and IP from second message):
 			self.assertTrue(_test('-o', 'ID:"<fid>" | IP:<ip> | U:<F-USER>', log, 
 				flt+'[failregex="'
-				  '^'+prefix+'User <F-USER>\S+</F-USER> not allowed\n'
-				  '^'+prefix+'Received disconnect from <F-ID><ADDR> port \d+</F-ID>'
+				  '^'+prefix+r'User <F-USER>\S+</F-USER> not allowed'+'\n'
+				  '^'+prefix+r'Received disconnect from <F-ID><ADDR> port \d+</F-ID>'
 				'"]'))
 			self.assertLogged('ID:"192.0.2.76 port 58846" | IP:192.0.2.76 | U:root')
 			self.pruneLog()
 		# first with sshd and prefregex:
 		_test_variants()
 		# the same without prefregex and MLFID directly in failregex (no merge with prefregex groups):
-		_test_variants('common', prefix="\s*\S+ sshd\[<F-MLFID>\d+</F-MLFID>\]:\s+")
+		_test_variants('common.conf', prefix=r"\s*\S+ sshd\[<F-MLFID>\d+</F-MLFID>\]:\s+")
 
 	def testNoDateTime(self):
 		# datepattern doesn't match:
@@ -483,7 +500,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		# complex substitution using tags and message (ip, user, msg):
 		self.assertTrue(_test_exec('-o', '<ip>, <F-USER>, <msg>',
 			'-c', CONFIG_DIR, '--usedns', 'no',
-			STR_ML_SSHD + "\n" + STR_ML_SSHD_OK, 'sshd[logtype=short, publickey=invalid]'))
+			STR_ML_SSHD + "\n" + STR_ML_SSHD_OK, 'sshd.conf[logtype=short, publickey=invalid]'))
 		# be sure we don't have IP in one line and have it in another:
 		lines = STR_ML_SSHD.split("\n")
 		self.assertTrue('192.0.2.2' not in lines[-2] and '192.0.2.2' in lines[-1])
@@ -499,7 +516,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		self.pruneLog("[test-phase 1] mode=aggressive & publickey=nofail + OK (accepted)")
 		self.assertTrue(_test_exec('-o', '<ip>, <F-USER>, <msg>',
 			'-c', CONFIG_DIR, '--usedns', 'no',
-			STR_ML_SSHD + "\n" + STR_ML_SSHD_OK, 'sshd[logtype=short, mode=aggressive]'))
+			STR_ML_SSHD + "\n" + STR_ML_SSHD_OK, 'sshd.conf[logtype=short, mode=aggressive]'))
 		self.assertLogged(
 			'192.0.2.2, git, '+lines[-4],
 			'192.0.2.2, git, '+lines[-3],
@@ -513,7 +530,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		self.pruneLog("[test-phase 2] mode=aggressive & publickey=nofail + FAIL (closed on preauth)")
 		self.assertTrue(_test_exec('-o', '<ip>, <F-USER>, <msg>',
 			'-c', CONFIG_DIR, '--usedns', 'no',
-			STR_ML_SSHD + "\n" + STR_ML_SSHD_FAIL, 'sshd[logtype=short, mode=aggressive]'))
+			STR_ML_SSHD + "\n" + STR_ML_SSHD_FAIL, 'sshd.conf[logtype=short, mode=aggressive]'))
 		# 192.0.2.1 should be found for every failure (2x failed key + 1x closed):
 		lines = STR_ML_SSHD.split("\n")[0:2] + STR_ML_SSHD_FAIL.split("\n")[-1:]
 		self.assertLogged(
@@ -534,7 +551,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 			'svc[2] connect started 192.0.2.4\n'
 			'svc[2] connect authorized 192.0.2.4\n'
 			'svc[2] connect finished 192.0.2.4\n',
-			'common[prefregex="^svc\[<F-MLFID>\d+</F-MLFID>\] connect <F-CONTENT>.+</F-CONTENT>$"'
+			r'common.conf[prefregex="^svc\[<F-MLFID>\d+</F-MLFID>\] connect <F-CONTENT>.+</F-CONTENT>$"'
 			', failregex="'
 			'^started\n'
 			'^<F-NOFAIL><F-MLFFORGET>finished</F-MLFFORGET></F-NOFAIL> <ADDR>\n'
@@ -545,7 +562,7 @@ class Fail2banRegexTest(LogCaptureTestCase):
 		self.assertNotLogged('failure from == 192.0.2.4 ==')
 
 	def testWrongFilterFile(self):
-		# use test log as filter file to cover eror cases...
+		# use test log as filter file to cover error cases...
 		self.assertFalse(_test_exec(
 			FILENAME_ZZZ_GEN, FILENAME_ZZZ_GEN
 		))
@@ -589,8 +606,8 @@ class Fail2banRegexTest(LogCaptureTestCase):
 				# test on unicode string containing \x0A as part of uni-char,
 				# it must produce exactly 2 lines (both are failures):
 				for l in (
-					u'1490349000 \u20AC Failed auth: invalid user Test\u020A from 192.0.2.1\n',
-					u'1490349000 \u20AC Failed auth: invalid user TestI from 192.0.2.2\n'
+					'1490349000 \u20AC Failed auth: invalid user Test\u020A from 192.0.2.1\n',
+					'1490349000 \u20AC Failed auth: invalid user TestI from 192.0.2.2\n'
 				):
 					fout.write(l.encode(enc))
 				fout.close()
